@@ -17,16 +17,23 @@ class MeiliSearchApiError(MeiliSearchError):
 
     def __init__(self, error: str, request: Response) -> None:
         self.status_code = request.status_code
+        self.error_code = None
+        self.error_link = None
+
         if request.text:
-            self.message = f'{json.loads(request.text)["message"]}'
-            self.error_code = f'{json.loads(request.text)["errorCode"]}'
-            self.error_link = f'{json.loads(request.text)["errorLink"]}'
+            json_data = json.loads(request.text)
+            self.message = json_data.get('message')
+            self.error_code = json_data.get('errorCode')
+            self.error_link = json_data.get('errorLink')
         else:
             self.message = error
         super().__init__(self.message)
 
     def __str__(self) -> str:
-        return f'MeiliSearchApiError. Error code: {self.error_code}. Error message: {self.message}. Error documentation: {self.error_link}'
+        if self.error_code and self.error_link:
+            return f'MeiliSearchApiError. Error code: {self.error_code}. Error message: {self.message}. Error documentation: {self.error_link}'
+
+        return f'MeiliSearchApiError. {self.message}'
 
 class MeiliSearchCommunicationError(MeiliSearchError):
     """Error when connecting to MeiliSearch"""
